@@ -104,6 +104,9 @@ c       following are to be kept inside
       integer kiap 
       integer kicp 
       integer kiat
+      integer check
+      data check/0/
+      save check
 
       save ke0n, kicz, kiap, kicp, kiat
 
@@ -120,7 +123,7 @@ c       following are to be kept inside
 
       kicz=iabs(kicp)/2+1 !primary particle class (1- pion, 2 - nucleon, 3 - kaon)
       xs=qgsect(ke0n,kicz,kiap,kiat) !get particle production cross section
-
+      check= 1
       return
 c     *********************************
       entry cqQGSint( e0n, icz, iap, icp, iat )
@@ -144,41 +147,45 @@ c      ebal(4)=0.d0
 c      aknn=0.d0
 c      ach=0.d0
 c       call rmmaq( iseed(1,iseq), iseq, 'r' )    !get random seed
+      if(check .eq. 0) then
+         if(pj.code .eq. klambda) then
+            call chAcolAdhoc(pj, iat, iz, a, ntp)
+         elseif(pj.code .eq. keta) then
+c                  at Ultra H.E, eta may collide.
+            call chAcolAdhoc(pj, iat, iz, a, ntp)
+         else           
+            write(0,*) ' check=0 in  qgsjet interface'
+            write(0,*) ' pj=',pj.code,pj.subcode,pj.charge,pj.fm.p(4)
+         endif
+      endif
+      if(check .eq. 1) then
+         kiat = iat             ! may not be the same as iat from cxsecqgs
 
-       kiat = iat  ! may not be the same as iat from cxsecqgs
-       if(pj.code .eq. keta) then
-c           at Ultra H.E, eta may collide.
-          call chAcolAdhoc(pj, iat, iz, a, ntp)
-       else
-          call qgini( ke0n, kicp, kiap, iat) !initialize current interaction
-          call qgconf           !inelastic interaction
+         call qgini( ke0n, kicp, kiap, iat) !initialize current interaction
+         call qgconf            !inelastic interaction
 c           next is projectile fragments
-          ntp = 0
-          do isf = 1, nsf       !loop over produced fragments
-             mfrag = iaf(isf)   !fragment mass number
-             zfrag = pj.charge*mfrag/kiap ! fragment charge
-             ntp = ntp + 1
+         ntp = 0
+         do isf = 1, nsf        !loop over produced fragments
+            mfrag = iaf(isf)    !fragment mass number
+            zfrag = pj.charge*mfrag/kiap ! fragment charge
+            ntp = ntp + 1
 c                set this heavy in a
-             call cmkptc(kgnuc, mfrag, zfrag, a(ntp))
-             a(ntp).fm.p(4) = ke0n*mfrag
-          enddo
+            call cmkptc(kgnuc, mfrag, zfrag, a(ntp))
+            a(ntp).fm.p(4) = ke0n*mfrag
+         enddo
 c          set fragment Pt
-          call csampFragMom( a, ntp )
-          do  is = 1, nsp       !loop over produced particles
-             ntp = ntp + 1
-             ic=ich(is)    
-             call cQGScode2cos(ic, a(ntp))
-             do i=1,4
-                a(ntp).fm.p(5-i)=esp(i,is) !particle 4-vector
-             enddo 
-c///////
-c          write(0,*) ' sec;',ntp, ' code=',a(ntp).code,
-c     *   ' chg=', a(ntp).charge, ' E=',a(ntp).fm.p(4), 
-c     *    ' pz=',a(ntp).fm.p(3)
-c/////
-          enddo
-       endif
-
+         call csampFragMom( a, ntp )
+         do  is = 1, nsp        !loop over produced particles
+            ntp = ntp + 1
+            ic=ich(is)    
+            call cQGScode2cos(ic, a(ntp))
+            do i=1,4
+               a(ntp).fm.p(5-i)=esp(i,is) !particle 4-vector
+            enddo 
+         enddo
+         check = 0
+      endif
+         
 c     -------------- rotate so that we get the same coordinate as pj
        call crot3mom( pj, a, ntp ) 
        if( pj.code .eq. kpion .and. pj.charge .eq. 0) then
@@ -263,8 +270,6 @@ c       -2 - p~, 2 - p, -3 - n~, 3 - n, -4 - k^-, 4 - k+, -5 - k0~, 5 - k0)
 
       character*80 msg
 
-      subcode = regptcl
-
       if(icp .eq. -1) then
          code = kpion
          charge = -1
